pub struct DvmBasicBlock { /* private fields */ }Expand description
Type alias for Shuriken’s hdvmbasicblock_t
Structure that stores information of a basic block
Implementations
Sourceimpl DvmBasicBlock
impl DvmBasicBlock
pub fn from_ptr(ptr: hdvmbasicblock_t_) -> Self
Sourcepub fn n_of_instructions(&self) -> usize
pub fn n_of_instructions(&self) -> usize
Return the number of instructions in the block
Sourcepub fn instructions(&self) -> &[DvmInstruction]
pub fn instructions(&self) -> &[DvmInstruction]
Return a reference to the pointer to the instructions in the block
Sourcepub fn catch_block(&self) -> bool
pub fn catch_block(&self) -> bool
Return the is it a catch block
Sourcepub fn handler_type(&self) -> &str
pub fn handler_type(&self) -> &str
Return a reference to the string value of the handler type
Sourcepub fn block_string(&self) -> &str
pub fn block_string(&self) -> &str
Return a reference to the whole representation of a basic block in string format